{% extends 'juntagrico/menu/admin.html' %}
{% load i18n %}
{% load juntagrico.config %}
{% block extend %}
    <li class="nav-item">
        {% vocabulary "assignment_pl" as v_assignment_pl %}
        <a class="nav-link" href="{% url 'juntagrico-assignment-request:list' %}">
            {% blocktrans %}Angemeldete {{ v_assignment_pl }}{% endblocktrans %}
        </a>
    </li>
    {{ block.super }}
{% endblock %}
