{% extends 'juntagrico/menu/user.html' %}
{% load i18n %}
{% load juntagrico.common %}
{% load juntagrico.config %}
{% block extend %}
    <li class="nav-item">
        {% vocabulary "assignment" as v_assignment %}
        <a class="nav-link {{ request|activemenu:"request_assignment" }}" 
           href="{% url 'juntagrico-assignment-request:request' %}">
            {% blocktrans %}{{ v_assignment }} melden{% endblocktrans %}
        </a>
    </li>
    {{ block.super }}
{% endblock %}
