# Generated by Django 4.2.9 on 2024-01-08 20:06

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('juntagrico_assignment_request', '0004_auto_20211207_1101'),
    ]

    operations = [
        migrations.AlterField(
            model_name='assignmentrequest',
            name='amount',
            field=models.FloatField(default=1.0, validators=[django.core.validators.MinValueValidator(0)], verbose_name='Wert'),
        ),
    ]
